@@ -87,12 +87,14 @@ not_greater_than = condition.not_greater_than
 not_in_list = condition.not_in_list
 not_less_than = condition.not_less_than
 order_by = condition.order_by
+select_columns = condition.select_columns
 ORDER_ASC = condition.OrderType.ASC
 ORDER_DESC = condition.OrderType.DESC
 
 transactional_read = decorator.transactional_read
 transactional_write = decorator.transactional_write
 
+SchemaUpdate = update_module.SchemaUpdate
 CreateTable = update_module.CreateTable
 DropTable = update_module.DropTable
 AddColumn = update_module.AddColumn
