@@ -19,15 +19,15 @@ from spanner_orm.admin import schema
 
 
 class IndexColumnSchema(schema.InformationSchema):
-  """Model for interacting with Spanner index column schema table."""
+    """Model for interacting with Spanner index column schema table."""
 
-  __table__ = 'information_schema.index_columns'
-  table_catalog = field.Field(field.String, primary_key=True)
-  table_schema = field.Field(field.String, primary_key=True)
-  table_name = field.Field(field.String, primary_key=True)
-  index_name = field.Field(field.String, primary_key=True)
-  column_name = field.Field(field.String, primary_key=True)
-  ordinal_position = field.Field(field.Integer, nullable=True)
-  column_ordering = field.Field(field.String, nullable=True)
-  is_nullable = field.Field(field.String)
-  spanner_type = field.Field(field.String)
+    __table__ = "information_schema.index_columns"
+    table_catalog = field.Field(field.String, primary_key=True)
+    table_schema = field.Field(field.String, primary_key=True)
+    table_name = field.Field(field.String, primary_key=True)
+    index_name = field.Field(field.String, primary_key=True)
+    column_name = field.Field(field.String, primary_key=True)
+    ordinal_position = field.Field(field.Integer, nullable=True)
+    column_ordering = field.Field(field.String, nullable=True)
+    is_nullable = field.Field(field.String)
+    spanner_type = field.Field(field.String)
